@@ -1,5 +1,5 @@
 # command_line
-__version__ = "0.2.4"
+__version__ = "0.2.6"
 SUMO_COMMANDS = ["prepare", "run", "evaluate", "interpret"]
 
 # prepare
@@ -29,7 +29,7 @@ PREPARE_ARGS = ["infiles", "outfile"] + list(PREPARE_DEFAULTS.keys())  # 3 posit
 CLUSTER_METHODS = ["max_value", "spectral"]
 RUN_DEFAULTS = {
     "sparsity": [0.1],
-    "n": 50,
+    "n": 60,
     "method": "max_value",
     "max_iter": 500,
     "tol": 1e-5,
@@ -37,7 +37,9 @@ RUN_DEFAULTS = {
     "logfile": None,
     "log": "INFO",
     "h_init": None,
-    "t": 1
+    "t": 1,
+    "subsample": 0.05,
+    "rep": 5
 }
 RUN_ARGS = ["infile", "k", "outdir"] + list(RUN_DEFAULTS.keys())  # 3 positional args
 
@@ -68,3 +70,8 @@ INTERPRET_ARGS = ['sumo_results', 'infiles', 'output_prefix'] + list(INTERPRET_D
 # utils
 LOG_LEVELS = ['DEBUG', 'INFO', 'WARNING']
 CLUSTER_METRICS = ['NMI', 'purity', 'ARI']
+COLOR_CODES = {
+    "blue": {"light": "#3C548899", "dark": "#3C5488FF"},
+    "red": {"light": "#DC000099", "dark": "#DC0000FF"},
+    "green": {"light": "#00A08799", "dark": "#00A087FF"}
+}
