@@ -5,10 +5,11 @@ import pytest
 
 def test_parse_args(capsys):
     correct = [
-        "./sumo.py prepare infile type outfile",
-        "./sumo.py prepare infile1,infile2 type outfile",
-        "./sumo.py prepare infile type1,type2 outfile",
+        "./sumo.py prepare infile outfile",
+        "./sumo.py prepare infile1,infile2 outfile",
         "./sumo.py run infile 2 outfile",
+        "./sumo.py run infile 2,10 outfile",
+        "./sumo.py evaluate infile labels",
         "./sumo.py"
     ]
 
@@ -26,6 +27,7 @@ def test_parse_args(capsys):
         "./sumo.py run infile outfile",
         "./sumo.py run infile two outfile",
         "./sumo.py run infile 2.5 outfile",
+        "./sumo.py evaluate infile",
         "./sumo.py not_a_command"
     ]
 
